@@ -26,7 +26,8 @@
 G_BEGIN_DECLS
 
 G_GNUC_INTERNAL
-gboolean	_gspell_utils_is_digit			(const gchar *text);
+gboolean	_gspell_utils_is_digit			(const gchar *text,
+							 gssize       text_length);
 
 G_GNUC_INTERNAL
 gboolean	_gspell_utils_skip_no_spell_check	(GtkTextIter       *start,
